[patch] bfd/*: Fix comment typos.

Kazu Hirata kazu@cs.umass.edu
Sun Nov 30 18:41:00 GMT 2003


Hi,

Committed as obvious.  bfd-in2.h was renegerated.

Kazu Hirata

Index: ChangeLog
===================================================================
RCS file: /cvs/src/src/bfd/ChangeLog,v
retrieving revision 1.2358
diff -u -r1.2358 ChangeLog
--- ChangeLog	28 Nov 2003 20:07:44 -0000	1.2358
+++ ChangeLog	30 Nov 2003 18:31:41 -0000
@@ -3138,7 +3138,7 @@
 
 2003-05-04  H.J. Lu <hjl@gnu.org>
 
-	* elflink.h (elf_merge_symbol): Correctly handle weak definiton.
+	* elflink.h (elf_merge_symbol): Correctly handle weak definition.
 
 2003-05-04  H.J. Lu <hjl@gnu.org>
 
@@ -8442,7 +8442,7 @@
 	* config.bfd: Added DLX configuraton.
 	* Makefile.am: Added DLX configuraton.
 	* configure.in: Added DLX configuraton.
-	* archures.c: Add DLX architecure.
+	* archures.c: Add DLX architecture.
 	* reloc.c: Add DLX relocs.
 	* targets.c: Added DLX target vector.
 	* configure: Regenerate.
Index: bfd-in2.h
===================================================================
RCS file: /cvs/src/src/bfd/bfd-in2.h,v
retrieving revision 1.250
diff -u -r1.250 bfd-in2.h
--- bfd-in2.h	24 Nov 2003 18:06:39 -0000	1.250
+++ bfd-in2.h	30 Nov 2003 18:31:43 -0000
@@ -1932,7 +1932,7 @@
 
   /* If this field is non null, then the supplied function is
      called rather than the normal function.  This allows really
-     strange relocation methods to be accomodated (e.g., i960 callj
+     strange relocation methods to be accommodated (e.g., i960 callj
      instructions).  */
   bfd_reloc_status_type (*special_function)
     (bfd *, arelent *, struct bfd_symbol *, void *, asection *,
@@ -2551,7 +2551,7 @@
 /* IBM 370/390 relocations  */
   BFD_RELOC_I370_D12,
 
-/* The type of reloc used to build a contructor table - at the moment
+/* The type of reloc used to build a constructor table - at the moment
 probably a 32 bit wide absolute relocation, but the target can choose.
 It generally does map to one of the other relocation types.  */
   BFD_RELOC_CTOR,
@@ -2848,11 +2848,11 @@
   BFD_RELOC_V850_TDA_4_4_OFFSET,
 
 /* This is a 16 bit offset from the short data area pointer, with the
-bits placed non-contigously in the instruction.  */
+bits placed non-contiguously in the instruction.  */
   BFD_RELOC_V850_SDA_16_16_SPLIT_OFFSET,
 
 /* This is a 16 bit offset from the zero data area pointer, with the
-bits placed non-contigously in the instruction.  */
+bits placed non-contiguously in the instruction.  */
   BFD_RELOC_V850_ZDA_16_16_SPLIT_OFFSET,
 
 /* This is a 6 bit offset from the call table base pointer.  */
@@ -3209,7 +3209,7 @@
 included in the output.
 
 VTABLE_INHERIT is a zero-space relocation used to describe to the
-linker the inheritence tree of a C++ virtual function table.  The
+linker the inheritance tree of a C++ virtual function table.  The
 relocation's symbol should be the parent class' vtable, and the
 relocation should be located at the child vtable.
 
@@ -3318,7 +3318,7 @@
 /* Motorola 68HC11 reloc.
 This reloc marks the beginning of a jump/call instruction.
 It is used for linker relaxation to correctly identify beginning
-of instruction and change some branchs to use PC-relative
+of instruction and change some branches to use PC-relative
 addressing mode.  */
   BFD_RELOC_M68HC11_RL_JUMP,
 
@@ -3530,7 +3530,7 @@
      <<BSF_LOCAL>>, <<BSF_FORT_COMM>>,  <<BSF_UNDEFINED>> or
      <<BSF_GLOBAL>>.  */
 
-  /* The symbol is a debugging record. The value has an arbitary
+  /* The symbol is a debugging record. The value has an arbitrary
      meaning, unless BSF_DEBUGGING_RELOC is also set.  */
 #define BSF_DEBUGGING  0x08
 
Index: ecoff.c
===================================================================
RCS file: /cvs/src/src/bfd/ecoff.c,v
retrieving revision 1.30
diff -u -r1.30 ecoff.c
--- ecoff.c	4 Nov 2003 10:41:51 -0000	1.30
+++ ecoff.c	30 Nov 2003 18:31:45 -0000
@@ -4129,7 +4129,7 @@
 
       if (bfd_get_flavour (input_bfd) == bfd_target_ecoff_flavour)
 	{
-	  /* Abitrarily set the symbolic header vstamp to the vstamp
+	  /* Arbitrarily set the symbolic header vstamp to the vstamp
 	     of the first object file in the link.  */
 	  if (symhdr->vstamp == 0)
 	    symhdr->vstamp
Index: ecofflink.c
===================================================================
RCS file: /cvs/src/src/bfd/ecofflink.c,v
retrieving revision 1.11
diff -u -r1.11 ecofflink.c
--- ecofflink.c	25 Jun 2003 06:40:19 -0000	1.11
+++ ecofflink.c	30 Nov 2003 18:31:46 -0000
@@ -2007,7 +2007,7 @@
   /* eraxxon: 'fdrtab_lookup' doesn't give what we want, at least for Compaq's
      C++ compiler 6.2.  Consider three FDRs with starting addresses of x, y,
      and z, respectively, such that x < y < z.  Assume further that
-     y < 'offset' < z.  It is possble at times that the PDR for 'offset' is
+     y < 'offset' < z.  It is possible at times that the PDR for 'offset' is
      associated with FDR x and *not* with FDR y.  Erg!!
 
      From a binary dump of my C++ test case 'moo' using Compaq's coffobjanl
@@ -2030,7 +2030,7 @@
 
      Since the FDRs that are causing so much havok (in this case) 1) do not
      describe actual files (fdr.rss == -1), and 2) contain only compiler
-     genarated routines, I thought a simple fix would be to exclude them from
+     generated routines, I thought a simple fix would be to exclude them from
      the FDR table in 'mk_fdrtab'.  But, besides not knowing for certain
      whether this would be correct, it creates an additional problem.  If we
      happen to ask for source file info on a compiler generated (procedure)
Index: format.c
===================================================================
RCS file: /cvs/src/src/bfd/format.c,v
retrieving revision 1.15
diff -u -r1.15 format.c
--- format.c	29 Jun 2003 10:06:39 -0000	1.15
+++ format.c	30 Nov 2003 18:31:46 -0000
@@ -425,7 +425,7 @@
   switch (format)
     {
     case bfd_object:
-      return "object";		/* Linker/assember/compiler output.  */
+      return "object";		/* Linker/assembler/compiler output.  */
     case bfd_archive:
       return "archive";		/* Object archive file.  */
     case bfd_core:
Index: hp300hpux.c
===================================================================
RCS file: /cvs/src/src/bfd/hp300hpux.c,v
retrieving revision 1.11
diff -u -r1.11 hp300hpux.c
--- hp300hpux.c	4 Nov 2003 11:30:54 -0000	1.11
+++ hp300hpux.c	30 Nov 2003 18:31:46 -0000
@@ -475,7 +475,7 @@
 
   /***************************************************************/
   /* check the header to see if it was generated by a bfd output */
-  /* this is detected rather bizarely by requiring a bunch of    */
+  /* this is detected rather bizarrely by requiring a bunch of   */
   /* header fields to be zero and an old unused field (now used) */
   /* to be set.                                                  */
   /***************************************************************/
@@ -588,7 +588,7 @@
      assignment to the strings pointer is done after we're thru using
      the nlist so we don't overwrite anything important. */
 
-  /* OK, now walk the new symtable, cacheing symbol properties */
+  /* OK, now walk the new symtable, caching symbol properties */
   {
     aout_symbol_type *cache_ptr = cached;
     aout_symbol_type cache_save;
@@ -611,7 +611,7 @@
 	  return FALSE;
 
 	/********************************************************/
-	/* for hpux, the 'lenght' value indicates the length of */
+	/* for hpux, the 'length' value indicates the length of */
 	/* the symbol name which follows the nlist entry.       */
 	/********************************************************/
 	if (length)
Index: i386linux.c
===================================================================
RCS file: /cvs/src/src/bfd/i386linux.c,v
retrieving revision 1.10
diff -u -r1.10 i386linux.c
--- i386linux.c	25 Jun 2003 06:40:21 -0000	1.10
+++ i386linux.c	30 Nov 2003 18:31:47 -0000
@@ -112,7 +112,7 @@
 #endif
 
 /* This special symbol is a set vector that contains a list of
-   pointers to fixup tables.  It will be present in any dynamicly
+   pointers to fixup tables.  It will be present in any dynamically
    linked file.  The linker generated fixup table should also be added
    to the list, and it should always appear in the second slot (the
    first one is a dummy with a magic number that is defined in
Index: ieee.c
===================================================================
RCS file: /cvs/src/src/bfd/ieee.c,v
retrieving revision 1.35
diff -u -r1.35 ieee.c
--- ieee.c	4 Nov 2003 10:41:51 -0000	1.35
+++ ieee.c	30 Nov 2003 18:31:48 -0000
@@ -1043,7 +1043,7 @@
 	    (void) must_parse_int (&(ieee->h));
 	    /* Fetch the default size if not resolved.  */
 	    size = must_parse_int (&(ieee->h));
-	    /* Fetch the defautlt value if available.  */
+	    /* Fetch the default value if available.  */
 	    if (! parse_int (&(ieee->h), &value))
 	      {
 		value = 0;
@@ -1639,7 +1639,7 @@
     const bfd_arch_info_type *arch;
     char family[10];
 
-    /* IEEE does not specify the format of the processor identificaton
+    /* IEEE does not specify the format of the processor identification
        string, so the compiler is free to put in it whatever it wants.
        We try here to recognize different processors belonging to the
        m68k family.  Code for other processors can be added here.  */
Index: m68klinux.c
===================================================================
RCS file: /cvs/src/src/bfd/m68klinux.c,v
retrieving revision 1.13
diff -u -r1.13 m68klinux.c
--- m68klinux.c	25 Jun 2003 06:40:22 -0000	1.13
+++ m68klinux.c	30 Nov 2003 18:31:48 -0000
@@ -113,7 +113,7 @@
 #endif
 
 /* This special symbol is a set vector that contains a list of
-   pointers to fixup tables.  It will be present in any dynamicly
+   pointers to fixup tables.  It will be present in any dynamically
    linked file.  The linker generated fixup table should also be added
    to the list, and it should always appear in the second slot (the
    first one is a dummy with a magic number that is defined in
Index: mipsbsd.c
===================================================================
RCS file: /cvs/src/src/bfd/mipsbsd.c,v
retrieving revision 1.12
diff -u -r1.12 mipsbsd.c
--- mipsbsd.c	31 Oct 2003 05:32:45 -0000	1.12
+++ mipsbsd.c	30 Nov 2003 18:31:49 -0000
@@ -220,7 +220,7 @@
       && (symbol->flags & BSF_WEAK) == 0)
     return bfd_reloc_undefined;
 
-  /* Work out which section the relocation is targetted at and the
+  /* Work out which section the relocation is targeted at and the
      initial relocation command value.  */
   if (bfd_is_com_section (symbol->section))
     relocation = 0;
@@ -271,7 +271,7 @@
       && (symbol->flags & BSF_WEAK) == 0)
     return bfd_reloc_undefined;
 
-  /* Work out which section the relocation is targetted at and the
+  /* Work out which section the relocation is targeted at and the
      initial relocation command value.  */
   if (bfd_is_com_section (symbol->section))
     relocation = 0;
Index: oasys.c
===================================================================
RCS file: /cvs/src/src/bfd/oasys.c,v
retrieving revision 1.21
diff -u -r1.21 oasys.c
--- oasys.c	4 Nov 2003 10:41:52 -0000	1.21
+++ oasys.c	30 Nov 2003 18:31:49 -0000
@@ -324,7 +324,7 @@
 
   /*
     There isn't a magic number in an Oasys archive, so the best we
-    can do to verify reasnableness is to make sure that the values in
+    can do to verify reasonableness is to make sure that the values in
     the header are too weird
     */
 
Index: opncls.c
===================================================================
RCS file: /cvs/src/src/bfd/opncls.c,v
retrieving revision 1.19
diff -u -r1.19 opncls.c
--- opncls.c	20 Oct 2003 14:38:39 -0000	1.19
+++ opncls.c	30 Nov 2003 18:31:50 -0000
@@ -201,7 +201,7 @@
 	descriptors for other opens), with the supplied @var{fd} used as
 	an initial file descriptor (but subject to closure at any time),
 	call bfd_set_cacheable(bfd, 1) on the returned BFD.  The default
-	is to assume no cacheing; the file descriptor will remain open
+	is to assume no caching; the file descriptor will remain open
 	until <<bfd_close>>, and will not be affected by BFD operations
 	on other files.
 
Index: peXXigen.c
===================================================================
RCS file: /cvs/src/src/bfd/peXXigen.c,v
retrieving revision 1.18
diff -u -r1.18 peXXigen.c
--- peXXigen.c	10 Nov 2003 17:04:54 -0000	1.18
+++ peXXigen.c	30 Nov 2003 18:31:51 -0000
@@ -645,7 +645,7 @@
 
   if (extra->DataDirectory[1].VirtualAddress == 0)
     /* Until other .idata fixes are made (pending patch), the entry for
-       .idata is needed for backwards compatability.  FIXME.  */
+       .idata is needed for backwards compatibility.  FIXME.  */
     add_data_entry (abfd, extra, 1, ".idata", ib);
     
   /* For some reason, the virtual size (which is what's set by
@@ -969,7 +969,7 @@
       && strcmp (scnhdr_int->s_name, ".text") == 0)
     {
       /* By inference from looking at MS output, the 32 bit field
-	 which is the combintion of the number_of_relocs and
+	 which is the combination of the number_of_relocs and
 	 number_of_linenos is used for the line number count in
 	 executables.  A 16-bit field won't do for cc1.  The MS
 	 document says that the number of relocs is zero for
Index: reloc.c
===================================================================
RCS file: /cvs/src/src/bfd/reloc.c,v
retrieving revision 1.95
diff -u -r1.95 reloc.c
--- reloc.c	31 Oct 2003 05:32:46 -0000	1.95
+++ reloc.c	30 Nov 2003 18:31:52 -0000
@@ -319,7 +319,7 @@
 .
 .  {* If this field is non null, then the supplied function is
 .     called rather than the normal function.  This allows really
-.     strange relocation methods to be accomodated (e.g., i960 callj
+.     strange relocation methods to be accommodated (e.g., i960 callj
 .     instructions).  *}
 .  bfd_reloc_status_type (*special_function)
 .    (bfd *, arelent *, struct bfd_symbol *, void *, asection *,
@@ -627,7 +627,7 @@
 			      / bfd_octets_per_byte (abfd)))
     return bfd_reloc_outofrange;
 
-  /* Work out which section the relocation is targetted at and the
+  /* Work out which section the relocation is targeted at and the
      initial relocation command value.  */
 
   /* Get symbol value.  (Common symbols are special.)  */
@@ -1017,7 +1017,7 @@
 			      / bfd_octets_per_byte (abfd)))
     return bfd_reloc_outofrange;
 
-  /* Work out which section the relocation is targetted at and the
+  /* Work out which section the relocation is targeted at and the
      initial relocation command value.  */
 
   /* Get symbol value.  (Common symbols are special.)  */
@@ -2507,7 +2507,7 @@
 ENUM
   BFD_RELOC_CTOR
 ENUMDOC
-  The type of reloc used to build a contructor table - at the moment
+  The type of reloc used to build a constructor table - at the moment
   probably a 32 bit wide absolute relocation, but the target can choose.
   It generally does map to one of the other relocation types.
 
@@ -2971,12 +2971,12 @@
   BFD_RELOC_V850_SDA_16_16_SPLIT_OFFSET
 ENUMDOC
   This is a 16 bit offset from the short data area pointer, with the
-  bits placed non-contigously in the instruction.
+  bits placed non-contiguously in the instruction.
 ENUM
   BFD_RELOC_V850_ZDA_16_16_SPLIT_OFFSET
 ENUMDOC
   This is a 16 bit offset from the zero data area pointer, with the
-  bits placed non-contigously in the instruction.
+  bits placed non-contiguously in the instruction.
 ENUM
   BFD_RELOC_V850_CALLT_6_7_OFFSET
 ENUMDOC
@@ -3482,7 +3482,7 @@
   included in the output.
 
   VTABLE_INHERIT is a zero-space relocation used to describe to the
-  linker the inheritence tree of a C++ virtual function table.  The
+  linker the inheritance tree of a C++ virtual function table.  The
   relocation's symbol should be the parent class' vtable, and the
   relocation should be located at the child vtable.
 
@@ -3675,7 +3675,7 @@
   Motorola 68HC11 reloc.
   This reloc marks the beginning of a jump/call instruction.
   It is used for linker relaxation to correctly identify beginning
-  of instruction and change some branchs to use PC-relative
+  of instruction and change some branches to use PC-relative
   addressing mode.
 ENUM
   BFD_RELOC_M68HC11_RL_GROUP
Index: reloc16.c
===================================================================
RCS file: /cvs/src/src/bfd/reloc16.c,v
retrieving revision 1.10
diff -u -r1.10 reloc16.c
--- reloc16.c	25 Jun 2003 06:40:22 -0000	1.10
+++ reloc16.c	30 Nov 2003 18:31:53 -0000
@@ -193,7 +193,7 @@
       bfd_size_type amt;
 
       /* Allocate and initialize the shrinks array for this section.
-	 The last element is used as an accumlator of shrinks.  */
+	 The last element is used as an accumulator of shrinks.  */
       amt = reloc_count + 1;
       amt *= sizeof (unsigned);
       shrinks = (unsigned *) bfd_zmalloc (amt);
Index: section.c
===================================================================
RCS file: /cvs/src/src/bfd/section.c,v
retrieving revision 1.65
diff -u -r1.65 section.c
--- section.c	3 Nov 2003 14:44:04 -0000	1.65
+++ section.c	30 Nov 2003 18:31:53 -0000
@@ -1065,7 +1065,7 @@
 
 |	func (abfd, the_section, obj);
 
-	This is the prefered method for iterating over sections; an
+	This is the preferred method for iterating over sections; an
 	alternative would be to use a loop:
 
 |	   section *p;
Index: simple.c
===================================================================
RCS file: /cvs/src/src/bfd/simple.c,v
retrieving revision 1.13
diff -u -r1.13 simple.c
--- simple.c	23 Sep 2003 03:59:25 -0000	1.13
+++ simple.c	30 Nov 2003 18:31:53 -0000
@@ -211,7 +211,7 @@
 
   /* The sections in ABFD may already have output sections and offsets set.
      Because this function is primarily for debug sections, and GCC uses the
-     knowledge that debug sections will generally have VMA 0 when emiting
+     knowledge that debug sections will generally have VMA 0 when emitting
      relocations between DWARF-2 sections (which are supposed to be
      section-relative offsets anyway), we need to reset the output offsets
      to zero.  We also need to arrange for section->output_section->vma plus
Index: som.c
===================================================================
RCS file: /cvs/src/src/bfd/som.c,v
retrieving revision 1.37
diff -u -r1.37 som.c
--- som.c	16 Oct 2003 04:11:08 -0000	1.37
+++ som.c	30 Nov 2003 18:31:56 -0000
@@ -1715,7 +1715,7 @@
 #ifndef NO_PCREL_MODES
 	/* If we have short and long pcrel modes, then generate the proper
 	   mode selector, then the pcrel relocation.  Redundant selectors
-	   will be eliminted as the relocs are sized and emitted.  */
+	   will be eliminated as the relocs are sized and emitted.  */
 	bfd_size_type amt = sizeof (int);
 	final_types[0] = (int *) bfd_alloc (abfd, amt);
 	if (!final_types[0])
@@ -2480,7 +2480,7 @@
   return TRUE;
 }
 
-/* Return TRUE if the given space containins the given subspace.  It
+/* Return TRUE if the given space contains the given subspace.  It
    is safe to assume space really is a space, and subspace really
    is a subspace.  */
 
@@ -2734,7 +2734,7 @@
 	    continue;
 
 	  /* If this subspace does not have real data, then we are
-	     finised with it.  */
+	     finished with it.  */
 	  if ((subsection->flags & SEC_HAS_CONTENTS) == 0)
 	    {
 	      som_section_data (subsection)->subspace_dict->fixup_request_index
@@ -3200,7 +3200,7 @@
   /* This gets a bit gruesome because of the compilation unit.  The
      strings within the compilation unit are part of the symbol
      strings, but don't have symbol_dictionary entries.  So, manually
-     write them and update the compliation unit header.  On input, the
+     write them and update the compilation unit header.  On input, the
      compilation unit header contains local copies of the strings.
      Move them aside.  */
   if (compilation_unit)
@@ -3906,7 +3906,7 @@
       section = section->next;
     }
 
-  /* All the subspace dictiondary records are written, and all the
+  /* All the subspace dictionary records are written, and all the
      fields are set up in the space dictionary records.
 
      Seek to the right location and start writing the space
@@ -3978,7 +3978,7 @@
       exec_header->exec_flags = obj_som_exec_data (abfd)->exec_flags;
 
       /* Oh joys.  Ram some of the BSS data into the DATA section
-	 to be compatable with how the hp linker makes objects
+	 to be compatible with how the hp linker makes objects
 	 (saves memory space).  */
       tmp = exec_header->exec_dsize;
       tmp = SOM_ALIGN (tmp, PA_PAGESIZE);
@@ -5780,7 +5780,7 @@
 		       + sizeof (struct lst_header)), SEEK_SET) != 0)
     return FALSE;
 
-  /* Initializae the cache and allocate space for the library symbols.  */
+  /* Initialize the cache and allocate space for the library symbols.  */
   ardata->cache = 0;
   amt = ardata->symdef_count;
   amt *= sizeof (carsym);
Index: som.h
===================================================================
RCS file: /cvs/src/src/bfd/som.h,v
retrieving revision 1.8
diff -u -r1.8 som.h
--- som.h	4 Nov 2003 11:30:54 -0000	1.8
+++ som.h	30 Nov 2003 18:31:56 -0000
@@ -210,7 +210,7 @@
    should be internal to the BFD backend.
 
    The idea is both SOM and ELF define these basic relocation
-   types so they map into a SOM or ELF specific reloation as
+   types so they map into a SOM or ELF specific relocation as
    appropriate.  This allows GAS to share much more code
    between the two object formats.  */
 
Index: sparclinux.c
===================================================================
RCS file: /cvs/src/src/bfd/sparclinux.c,v
retrieving revision 1.12
diff -u -r1.12 sparclinux.c
--- sparclinux.c	25 Jun 2003 06:40:22 -0000	1.12
+++ sparclinux.c	30 Nov 2003 18:31:56 -0000
@@ -113,7 +113,7 @@
 #endif
 
 /* This special symbol is a set vector that contains a list of
-   pointers to fixup tables.  It will be present in any dynamicly
+   pointers to fixup tables.  It will be present in any dynamically
    linked file.  The linker generated fixup table should also be added
    to the list, and it should always appear in the second slot (the
    first one is a dummy with a magic number that is defined in
Index: srec.c
===================================================================
RCS file: /cvs/src/src/bfd/srec.c,v
retrieving revision 1.26
diff -u -r1.26 srec.c
--- srec.c	4 Nov 2003 10:41:52 -0000	1.26
+++ srec.c	30 Nov 2003 18:31:57 -0000
@@ -1009,7 +1009,7 @@
 {
   unsigned int len = strlen (abfd->filename);
 
-  /* I'll put an arbitary 40 char limit on header size.  */
+  /* I'll put an arbitrary 40 char limit on header size.  */
   if (len > 40)
     len = 40;
 
Index: syms.c
===================================================================
RCS file: /cvs/src/src/bfd/syms.c,v
retrieving revision 1.34
diff -u -r1.34 syms.c
--- syms.c	31 Oct 2003 05:32:46 -0000	1.34
+++ syms.c	30 Nov 2003 18:31:58 -0000
@@ -133,9 +133,9 @@
 |	nm foo
 |	00012345 A dummy_symbol
 
-	Many formats cannot represent arbitary symbol information; for
+	Many formats cannot represent arbitrary symbol information; for
  	instance, the <<a.out>> object format does not allow an
-	arbitary number of sections. A symbol pointing to a section
+	arbitrary number of sections. A symbol pointing to a section
 	which is not one  of <<.text>>, <<.data>> or <<.bss>> cannot
 	be described.
 
@@ -222,7 +222,7 @@
 .     <<BSF_LOCAL>>, <<BSF_FORT_COMM>>,  <<BSF_UNDEFINED>> or
 .     <<BSF_GLOBAL>>.  *}
 .
-.  {* The symbol is a debugging record. The value has an arbitary
+.  {* The symbol is a debugging record. The value has an arbitrary
 .     meaning, unless BSF_DEBUGGING_RELOC is also set.  *}
 .#define BSF_DEBUGGING	0x08
 .
@@ -1222,7 +1222,7 @@
       long low, high;
       long mid = -1;
 
-      /* Cache non-existant or invalid.  Do binary search on
+      /* Cache non-existent or invalid.  Do binary search on
          indextable.  */
       indexentry = NULL;
 
Index: targets.c
===================================================================
RCS file: /cvs/src/src/bfd/targets.c,v
retrieving revision 1.101
diff -u -r1.101 targets.c
--- targets.c	4 Nov 2003 10:41:52 -0000	1.101
+++ targets.c	30 Nov 2003 18:31:58 -0000
@@ -30,7 +30,7 @@
 	Targets
 
 DESCRIPTION
-	Each port of BFD to a different machine requries the creation
+	Each port of BFD to a different machine requires the creation
 	of a target back end. All the back end provides to the root
 	part of BFD is a structure containing pointers to functions
 	which perform certain low level operations on files. BFD
Index: tekhex.c
===================================================================
RCS file: /cvs/src/src/bfd/tekhex.c,v
retrieving revision 1.17
diff -u -r1.17 tekhex.c
--- tekhex.c	4 Nov 2003 10:41:52 -0000	1.17
+++ tekhex.c	30 Nov 2003 18:31:59 -0000
@@ -29,7 +29,7 @@
 	relocations. Their main application is communication with
 	devices like PROM programmers and ICE equipment.
 
-	It seems that the sections are descibed as being really big,
+	It seems that the sections are described as being really big,
         the example I have says that the text section is 0..ffffffff.
 	BFD would barf with this, many apps would try to alloc 4GB to
 	read in the file.
Index: versados.c
===================================================================
RCS file: /cvs/src/src/bfd/versados.c,v
retrieving revision 1.19
diff -u -r1.19 versados.c
--- versados.c	4 Nov 2003 10:41:52 -0000	1.19
+++ versados.c	30 Nov 2003 18:31:59 -0000
@@ -32,9 +32,9 @@
 
    A VERSAdos file looks like contains
 
-   o Indentification Record
+   o Identification Record
    o External Symbol Definition Record
-   o Object Text Recrod
+   o Object Text Record
    o End Record
 
  */
Index: vms-gsd.c
===================================================================
RCS file: /cvs/src/src/bfd/vms-gsd.c,v
retrieving revision 1.12
diff -u -r1.12 vms-gsd.c
--- vms-gsd.c	30 Nov 2002 08:39:40 -0000	1.12
+++ vms-gsd.c	30 Nov 2003 18:31:59 -0000
@@ -788,7 +788,7 @@
 	  last_index++;
 	}
 
-      /* Don't know if this is neccesary for the linker but for now it keeps
+      /* Don't know if this is necessary for the linker but for now it keeps
 	 vms_slurp_gsd happy  */
 
       sname = (char *)section->name;
Index: vms-hdr.c
===================================================================
RCS file: /cvs/src/src/bfd/vms-hdr.c,v
retrieving revision 1.12
diff -u -r1.12 vms-hdr.c
--- vms-hdr.c	30 Nov 2002 08:39:40 -0000	1.12
+++ vms-hdr.c	30 Nov 2003 18:31:59 -0000
@@ -206,7 +206,7 @@
 /*-----------------------------------------------------------------------------*/
 /* Output routines.  */
 
-/* Manufacure a VMS like time on a unix based system.
+/* Manufacture a VMS like time on a unix based system.
    stolen from obj-vms.c  */
 
 static unsigned char *
Index: vms-misc.c
===================================================================
RCS file: /cvs/src/src/bfd/vms-misc.c,v
retrieving revision 1.17
diff -u -r1.17 vms-misc.c
--- vms-misc.c	4 Nov 2003 10:41:52 -0000	1.17
+++ vms-misc.c	30 Nov 2003 18:32:00 -0000
@@ -49,7 +49,7 @@
    ...
    9	almost everything
 
-   level is also identation level. Indentation is performed
+   level is also indentation level. Indentation is performed
    if level > 0
 	*/
 
@@ -668,7 +668,7 @@
 
   _bfd_vms_output_short (abfd, (unsigned int) rectype);
 
-  /* save current output position to fill in lenght later  */
+  /* save current output position to fill in length later  */
 
   if (PRIV (push_level) > 0)
     PRIV (length_pos) = PRIV (output_size);
Index: xcofflink.c
===================================================================
RCS file: /cvs/src/src/bfd/xcofflink.c,v
retrieving revision 1.31
diff -u -r1.31 xcofflink.c
--- xcofflink.c	25 Jun 2003 06:40:22 -0000	1.31
+++ xcofflink.c	30 Nov 2003 18:32:02 -0000
@@ -1248,7 +1248,7 @@
 		}
 	      linoff = (auxlin.x_sym.x_fcnary.x_fcn.x_lnnoptr
 			- enclosing->line_filepos);
-	      /* explict cast to bfd_signed_vma for compiler */
+	      /* explicit cast to bfd_signed_vma for compiler */
 	      if (linoff < (bfd_signed_vma) (enclosing->lineno_count * linesz))
 		{
 		  struct internal_lineno lin;
@@ -2898,7 +2898,7 @@
       xcoff_mark_symbol (info, hsym);
       hsym->flags |= (XCOFF_DEF_REGULAR | XCOFF_RTINIT);
 
-      /* __rtinit initalized */
+      /* __rtinit initialized */
       amt = sizeof (struct internal_ldsym);
       ldsym = (struct internal_ldsym *) bfd_malloc (amt);
 
Index: xsym.h
===================================================================
RCS file: /cvs/src/src/bfd/xsym.h,v
retrieving revision 1.5
diff -u -r1.5 xsym.h
--- xsym.h	4 Nov 2003 11:30:54 -0000	1.5
+++ xsym.h	30 Nov 2003 18:32:03 -0000
@@ -133,7 +133,7 @@
    (Note that having a single module copied into two resources is not
    possible).  Modules map back to their resource via an index into the
    resource table and an offset into the resource.  Modules also point
-   to their source files, both the definition module and implemention
+   to their source files, both the definition module and implementation
    module.  Because modules can be textually nested within other
    modules, a link to the parent (containing) module is required.  This
    module can textually contain other modules.  A link to the contiguous



More information about the Binutils mailing list
Index: mach-o.h
===================================================================
RCS file: /cvs/src/src/bfd/mach-o.h,v
retrieving revision 1.3
diff -u -r1.3 mach-o.h
--- mach-o.h	30 Nov 2002 08:39:40 -0000	1.3
+++ mach-o.h	30 Nov 2003 18:31:49 -0000
@@ -74,11 +74,11 @@
     BFD_MACH_O_LC_FVMFILE = 0x9,	/* Fixed VM file inclusion.  */
     BFD_MACH_O_LC_PREPAGE = 0xa,	/* Prepage command (internal use).  */
     BFD_MACH_O_LC_DYSYMTAB = 0xb,	/* Dynamic link-edit symbol table info.  */
-    BFD_MACH_O_LC_LOAD_DYLIB = 0xc,	/* Load a dynamicly linked shared library.  */
-    BFD_MACH_O_LC_ID_DYLIB = 0xd,	/* Dynamicly linked shared lib identification.  */
+    BFD_MACH_O_LC_LOAD_DYLIB = 0xc,	/* Load a dynamically linked shared library.  */
+    BFD_MACH_O_LC_ID_DYLIB = 0xd,	/* Dynamically linked shared lib identification.  */
     BFD_MACH_O_LC_LOAD_DYLINKER = 0xe,	/* Load a dynamic linker.  */
     BFD_MACH_O_LC_ID_DYLINKER = 0xf,	/* Dynamic linker identification.  */
-    BFD_MACH_O_LC_PREBOUND_DYLIB = 0x10,/* Modules prebound for a dynamicly.  */
+    BFD_MACH_O_LC_PREBOUND_DYLIB = 0x10,/* Modules prebound for a dynamically.  */
     BFD_MACH_O_LC_ROUTINES = 0x11,	/* Image routines.  */
     BFD_MACH_O_LC_SUB_FRAMEWORK = 0x12,	/* Sub framework.  */
     BFD_MACH_O_LC_SUB_UMBRELLA = 0x13,	/* Sub umbrella.  */
@@ -86,7 +86,7 @@
     BFD_MACH_O_LC_SUB_LIBRARY = 0x15,   /* Sub library.  */
     BFD_MACH_O_LC_TWOLEVEL_HINTS = 0x16,/* Two-level namespace lookup hints.  */
     BFD_MACH_O_LC_PREBIND_CKSUM = 0x17, /* Prebind checksum.  */
     /* Load a dynamicly linked shared library that is allowed to be
        missing (weak).  */
     BFD_MACH_O_LC_LOAD_WEAK_DYLIB = 0x18
   }
@@ -231,7 +231,7 @@
 bfd_mach_o_symtab_command;
 
 /* This is the second set of the symbolic information which is used to support
-   the data structures for the dynamicly link editor.
+   the data structures for the dynamically link editor.
 
    The original set of symbolic information in the symtab_command which contains
    the symbol and string tables must also be present when this load command is
@@ -250,7 +250,7 @@
        reference symbol table
        indirect symbol table
    The first three tables above (the table of contents, module table and
-   reference symbol table) are only present if the file is a dynamicly linked
+   reference symbol table) are only present if the file is a dynamically linked
    shared library.  For executable and object modules, which are files
    containing only one module, the information that would be in these three
    tables is determined as follows:
@@ -259,7 +259,7 @@
                       file is part of the module.
        reference symbol table - is the defined and undefined external symbols
 
-   For dynamicly linked shared library files this load command also contains
+   For dynamically linked shared library files this load command also contains
    offsets and sizes to the pool of relocation entries for all sections
    separated into two groups:
        external relocation entries
@@ -281,7 +281,7 @@
 
      The last two groups are used by the dynamic binding process to do the
      binding (indirectly through the module table and the reference symbol
-     table when this is a dynamicly linked shared library file).  */
+     table when this is a dynamically linked shared library file).  */
 
   unsigned long ilocalsym;    /* Index to local symbols.  */
   unsigned long nlocalsym;    /* Number of local symbols.  */
@@ -293,7 +293,7 @@
   /* For the for the dynamic binding process to find which module a symbol
      is defined in the table of contents is used (analogous to the ranlib
      structure in an archive) which maps defined external symbols to modules
-     they are defined in.  This exists only in a dynamicly linked shared
+     they are defined in.  This exists only in a dynamically linked shared
      library file.  For executable and object modules the defined external
      symbols are sorted by name and is use as the table of contents.  */
 
@@ -304,7 +304,7 @@
      table must reflect the modules that the file was created from.  This is
      done by having a module table that has indexes and counts into the merged
      tables for each module.  The module structure that these two entries
-     refer to is described below.  This exists only in a dynamicly linked
+     refer to is described below.  This exists only in a dynamically linked
      shared library file.  For executable and object modules the file only
      contains one module so everything in the file belongs to the module.  */
 
@@ -315,7 +315,7 @@
      indicates the external references (defined and undefined) each module
      makes.  For each module there is an offset and a count into the
      reference symbol table for the symbols that the module references.
-     This exists only in a dynamicly linked shared library file.  For
+     This exists only in a dynamically linked shared library file.  For
      executable and object modules the defined external symbols and the
      undefined external symbols indicates the external references.  */
 
@@ -363,7 +363,7 @@
 
   /* All the local relocation entries are grouped together (they are not
      grouped by their module since they are only used if the object is moved
-     from it staticly link edited address).  */
+     from it statically link edited address).  */
 
   unsigned long locreloff;    /* Offset to local relocation entries.  */
   unsigned long nlocrel;      /* Number of local relocation entries.  */
@@ -86,7 +86,7 @@
     BFD_MACH_O_LC_TWOLEVEL_HINTS = 0x16,/* Two-level namespace lookup hints.  */
     BFD_MACH_O_LC_PREBIND_CKSUM = 0x17, /* Prebind checksum.  */
-    /* Load a dynamicly linked shared library that is allowed to be
+    /* Load a dynamically linked shared library that is allowed to be
        missing (weak).  */
     BFD_MACH_O_LC_LOAD_WEAK_DYLIB = 0x18